"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

/*
 * This is the Hapi route handler that will be applied to the React application
 * route (usually a wildcard handling all paths).
 *
 * It is primarily responsible for:
 *
 * 1. Ensuring that the current URL pathname matches the language specified by
 *    the request - redirect if not
 * 2. Render the application in the requested language
 * 3. Set 'Vary' header in order to cache based on device type in header.
 *    If 'X-UA-Device' is present, after caching, Fastly rewrites
 *    the Vary header to 'User-Agent', in order for the google bots
 *    to crawl mobile and desktop versions of the site
 */
var _default = function _default(languageRenderers) {
  return function (request, h) {
    var pathname = request.getLangPrefixPath();

    if (pathname !== request.url.pathname) {
      // redirect to a host relative path, keeping query params intact
      return h.redirect("".concat(pathname).concat(request.url.search));
    }

    var requestLanguage = request.getLanguage();
    var renderRequest = languageRenderers[requestLanguage];
    return renderRequest(request, h).then(function (renderResult) {
      if (renderResult.redirect) {
        return h.redirect(renderResult.redirect.url).permanent(Boolean(renderResult.redirect.permanent));
      }

      return h.response(renderResult.result).code(renderResult.statusCode).header('vary', 'X-UA-Device'); // set by fastly
    }, function (err) {
      return err;
    } // 500 error - will only be thrown on bad implementation
    );
  };
};

exports.default = _default;
//# sourceMappingURL=handler.js.map