"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.onPreResponse = void 0;

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _react = _interopRequireDefault(require("react"));

var _server = _interopRequireDefault(require("react-dom/server"));

var _handler = _interopRequireDefault(require("./handler"));

var _click = require("mwp-tracking-plugin/lib/click");

var onPreResponse = {
  /*
   * This function processes the route response before it is sent to the client.
   *
   * - In dev, it transforms the generic 500 error response JSON into a full dev-
   *   friendly rendering of the stack trace.
   */
  method: function method(request, h) {
    var response = request.response;

    if (!response.isBoom || process.env.NODE_ENV === 'production') {
      return h.continue;
    }

    var error = response;

    var _require = require('redbox-react'),
        RedBoxError = _require.RedBoxError;

    var errorMarkup = _server.default.renderToString(_react.default.createElement(RedBoxError, {
      error: error
    }));

    return h.response("<!DOCTYPE html><html><body>".concat(errorMarkup, "</body></html>")).code(error.output.statusCode);
  }
};
/*
 * Wildcard route for all application GET requests - see the 'handler' module
 * for rendering details
 *
 * Route options:
 *
 * - `onPreResponse`: process the response before it is sent to client
 * - `state`: skip cookie validation because cookies can be set by other services
 *   on the same domain and may not conform to the validation rules that are
 *   used by Hapi
 */

exports.onPreResponse = onPreResponse;

var _default = function _default(languageRenderers) {
  return {
    method: 'GET',
    path: '/{wild*}',
    options: {
      ext: {
        onPreResponse: onPreResponse
      },
      plugins: (0, _defineProperty2.default)({
        'electrode-csrf-jwt': {
          enabled: true // need to generate tokens on page request

        }
      }, _click.CLICK_PLUGIN_NAME, {
        click: function click() {
          return true;
        } // always track clicks on server render

      }),
      state: {
        failAction: 'ignore' // ignore cookie validation, just accept

      }
    },
    handler: (0, _handler.default)(languageRenderers)
  };
};

exports.default = _default;
//# sourceMappingURL=route.js.map